@@ -133,9 +133,11 @@ gel_compile_node(GelETree *t,GString *gs)
 		break;
 	case FUNCTION_NODE:
 		g_assert(t->func.func->type==GEL_USER_FUNC);
-		g_assert(t->func.func->id==NULL);
+		/*g_assert(t->func.func->id==NULL);*/
 		g_string_sprintfa(gs,";%d",t->func.func->nargs);
 		g_string_sprintfa(gs,";%d",t->func.func->vararg);
+		g_string_sprintfa(gs,";%d",t->func.func->propagate_mod);
+		g_string_sprintfa(gs,";%d",t->func.func->no_mod_all_args);
 		for(li=t->func.func->named_args;li;li=g_slist_next(li)) {
 			GelToken *tok = li->data;
 			g_string_sprintfa(gs,";%s",tok->token);
@@ -180,6 +182,8 @@ gel_decompile_node(void)
 	int type = -1;
 	int nargs = -1;
 	int vararg = -1;
+	int propagate_mod = -1;
+	int no_mod_all_args = -1;
 	int quote;
 	int oper;
 	int i,j;
@@ -316,6 +320,16 @@ gel_decompile_node(void)
 		sscanf(p,"%d",&vararg);
 		if (vararg == -1) return NULL;
 
+		p = strtok(NULL,";");
+		if(!p) return NULL;
+		sscanf(p,"%d",&propagate_mod);
+		if (propagate_mod == -1) return NULL;
+
+		p = strtok(NULL,";");
+		if(!p) return NULL;
+		sscanf(p,"%d",&no_mod_all_args);
+		if (no_mod_all_args == -1) return NULL;
+
 		oli = NULL;
 		for(i=0;i<nargs;i++) {
 			p = strtok(NULL,";");
@@ -335,6 +349,8 @@ gel_decompile_node(void)
 		func = d_makeufunc(NULL,n,oli,nargs, NULL);
 		func->context = -1;
 		func->vararg = vararg ? 1 : 0;
+		func->propagate_mod = propagate_mod ? 1 : 0;
+		func->no_mod_all_args = no_mod_all_args ? 1 : 0;
 
 		GET_NEW_NODE(n);
 		n->type = FUNCTION_NODE;
